View source: R/plot.fdid_list.R
| plot.fdid_list | R Documentation |
Creates a comparison plot of point estimates and confidence intervals for every element of an 'fdid_list'.
## S3 method for class 'fdid_list'
plot(
x,
xlab = NULL,
ylab = NULL,
main = NULL,
ylim = NULL,
vertical = TRUE,
show_vartype = TRUE,
...
)
x |
An object of class '"fdid_list"'. |
xlab, ylab, main |
Axis labels and title. If 'NULL', sensible defaults are used. |
ylim |
Optional numeric vector of length two giving the *estimate-axis* limits. (Backward compatible: for horizontal plots this is the x-limit; for vertical plots this is the y-limit.) |
vertical |
Logical; default is |
show_vartype |
Logical; include vartype in labels. Default is |
... |
Additional graphics parameters passed to |
Invisibly returns 'x'; called for its side-effect of drawing a plot.
Rivka Lipkovitz, Enhan Liu
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.